=======================
Why the name kalasiris?
=======================

Ancient Egyptian women typically wore a simple sheath dress called
a *kalasiris*.

Goddesses were often shown wearing such a garment, and so the goddess
*Isis* is often depicted in a kalasiris.

Since this software is a Python wrapper for ISIS, it seemed like
an appropriate name, and it is unlikely to cause any name collisions
with anything else.
